@@ -11,7 +11,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,8 +46,8 @@
  * in David R. Hanson's excellent book "C Interfaces and Implementations".
  * See http://www.cs.princeton.edu/software/cii/
  *
- * @author http://www.tildeslash.com/
- * @see http://www.mmonit.com/
+ * @author https://www.tildeslash.com/
+ * @see https://mmonit.com/
  * @file
  */
 
@@ -91,7 +91,7 @@ void Exception_throw(const T *e, const char *func, const char *file, int line, c
                 if (message)
                         Str_copy(p->message, message, EXCEPTION_MESSAGE_LENGTH);
                 pop_exception_stack;
-                longjmp(p->env, Exception_thrown);
+                siglongjmp(p->env, Exception_thrown);
         } else if (message) {
                 ABORT("%s: %s\n raised in %s at %s:%d\n", e->name, message, func ? func : "?", file ? file : "?", line);
         } else {
