@@ -11,7 +11,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -157,8 +157,8 @@
  * @see SQLException.h IOException.h AssertException.h NumberFormatException.h
  * MemoryException.h
  *
- * @author http://www.tildeslash.com/
- * @see http://www.mmonit.com/
+ * @author https://www.tildeslash.com/
+ * @see https://mmonit.com/
  * @file
  */
 
@@ -181,8 +181,8 @@ typedef struct T {
 #define EXCEPTION_MESSAGE_LENGTH 511
 typedef struct Exception_Frame Exception_Frame;
 struct Exception_Frame {
-	int line;
-	jmp_buf env;
+        int line;
+        sigjmp_buf env;
         const char *func;
 	const char *file;
 	const T *exception;
@@ -241,7 +241,7 @@ void Exception_throw(const T *e, const char *func, const char *file, int line, c
         Exception_frame.message[0] = 0; \
         Exception_frame.prev = pthread_getspecific(Exception_Stack); \
         pthread_setspecific(Exception_Stack, &Exception_frame); \
-        Exception_flag = setjmp(Exception_frame.env); \
+        Exception_flag = sigsetjmp(Exception_frame.env, 0); \
         if (Exception_flag == Exception_entered) {
 
 
