@@ -10,7 +10,7 @@
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -30,8 +30,8 @@
 /**
  * System routines
  *
- * @author http://www.tildeslash.com/
- * @see http://www.mmonit.com/
+ * @author https://www.tildeslash.com/
+ * @see https://mmonit.com/
  * @file
  */
 
@@ -92,20 +92,4 @@ void System_debug(const char *d, ...) __attribute__((format (printf, 1, 2)));
 int System_descriptors(int guard);
 
 
-/**
- * Initialize the buf of size nbytes with random data.
- * @param buf The target buffer
- * @param nbtyes The target buffer size in bytes
- * @return true on success, otherwise false
- */
-bool System_random(void *buf, size_t nbytes);
-
-
-/**
- * Get random number
- * @return random number
- */
-unsigned long long System_randomNumber(void);
-
-
 #endif
