@@ -246,7 +246,25 @@ char *Time_str(time_t time, char result[static 30]);
 
 
 /**
- * Returns <code>time</code> as a date string. The <code>format</code>
+* Returns <code>time</code> as a date string in local time zone. The <code>format</code>
+* parameter determines the format of the string. The format specifiers
+* are the same as those used by <code>strftime(3)</code>. For instance to
+* specify a RFC822 time string on the format "Wed, 05 Feb 2003 01:16:44
+* +0100" the following format string is used:
+* <code>"%a, %d %b %Y %H:%M:%S %z"</code>
+* @param result The buffer to write the date string too
+* @param size Size of the result buffer
+* @param format A <code>strftime</code> format string
+* @param time Number of seconds since the Epoch
+* (00:00:00 UTC, January 1, 1970)
+* @return A pointer to the result buffer
+* @exception AssertException If <code>format</code> or <code>result</code>
+* is NULL
+*/
+char *Time_localFmt(char *result, int size, const char *format, time_t time);
+
+/**
+ * Returns <code>time</code> as a date string in UTC. The <code>format</code>
  * parameter determines the format of the string. The format specifiers
  * are the same as those used by <code>strftime(3)</code>. For instance to
  * specify a RFC822 time string on the format "Wed, 05 Feb 2003 01:16:44
@@ -347,9 +365,10 @@ int Time_incron(const char *cron, time_t time);
  * duration in microseconds. If sleep is interrupted by a signal,
  * the function aborts sleep and returns the number of remaining
  * microseconds.
- * @param microseconds The duration of the sleep in microseconds.
- * @return 0 if sleep was completed, number of remaining microseconds
- * if sleep was interrupted by a signal.
+ * @param microseconds The duration of the sleep in microseconds
+ * @return 0 if sleep was completed, -1 if microseconds is invalid
+ *         (negative or would overflow timespec on 32-bit systems),
+ *         or remaining microseconds if interrupted by a signal
  */
 long long Time_usleep(long long microseconds);
 
@@ -360,9 +379,34 @@ long long Time_usleep(long long microseconds);
  * resilient to interruptions by signals. If a signal interrupts
  * sleep, the function will continue to sleep for the remainder
  * of the specified duration after handling of the signal.
- * @param microseconds The duration of the sleep in microseconds.
+ * @param microseconds The duration of the sleep in microseconds
+ * @return true if sleep was completed, false if microseconds is invalid
  */
-void Time_usleepComplete(long long microseconds);
+bool Time_usleepComplete(long long microseconds);
+
+
+/**
+ * Suspends the calling process or thread for the specified
+ * duration in seconds. If sleep is interrupted by a signal,
+ * the function aborts sleep and returns the number of remaining
+ * seconds.
+ * @param seconds The duration of the sleep in seconds
+ * @return 0 if sleep was completed, -1 if seconds is invalid,
+ *         or remaining seconds if interrupted by a signal
+ */
+long Time_sleep(long seconds);
+
+
+/**
+ * Suspends the calling process or thread for the specified
+ * duration in seconds. Unlike Time_sleep, this function is
+ * resilient to interruptions by signals. If a signal interrupts
+ * sleep, the function will continue to sleep for the remainder
+ * of the specified duration after handling of the signal.
+ * @param seconds The duration of the sleep in seconds
+ * @return true if sleep was completed, false if seconds is invalid
+ */
+bool Time_sleepComplete(long seconds);
 
 
 /**
@@ -381,5 +425,4 @@ bool Time_backoff(bool predicate(void *args), void *args);
 
 //@}
 
-#undef T
 #endif
