@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -238,6 +238,8 @@ static bool _send(List_T list) {
                                                 "MIME-Version: 1.0\r\n"
                                                 "Content-Type: text/plain; charset=utf-8\r\n"
                                                 "Content-Transfer-Encoding: 8bit\r\n"
+                                                "X-Auto-Response-Suppress: All\r\n"
+                                                "Precedence: Bulk\r\n"
                                                 "Message-Id: <%lld.%llx@%s>\r\n"
                                                 "\r\n"
                                                 "%s",
