@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -76,11 +76,11 @@
 typedef enum {
         Process_Stopped = 0,
         Process_Started
-} __attribute__((__packed__)) Process_Status;
+} Process_Status;
 
 
-#define RETRY_INTERVAL 100000 // 100ms
-
+#define RETRY_INTERVAL 100000LL // 100ms in microseconds
+// TODO: Consider using Time_backoff instead for retry for simplification and clamped timeout
 
 /* ----------------------------------------------------------------- Private */
 
@@ -91,7 +91,7 @@ static int _getOutput(InputStream_T in, char *buf, int buflen) {
 }
 
 
-static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long long *timeout) {
+static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long long *usec_timeout) {
         assert(S);
         assert(c);
         assert(msg);
@@ -101,7 +101,7 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long
         TRY
         {
                 // May throw exception if the program doesn't exist (was removed while Monit was up)
-                C = Command_new(c->arg[0], NULL);
+                C = Command_new(c->arg[0]);
         }
         ELSE
         {
@@ -109,7 +109,7 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long
         }
         END_TRY;
         if (C) {
-                long long _timeoutMilli = *timeout / 1000.;
+                long long _timeoutMilli = *usec_timeout / 1000.;
                 for (int i = 1; i < c->length; i++)
                         Command_appendArgument(C, c->arg[i]);
                 if (c->has_uid)
@@ -138,25 +138,26 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long
                 if (P) {
                         do {
                                 Time_usleep(RETRY_INTERVAL);
-                                *timeout -= RETRY_INTERVAL;
-                        } while ((status = Process_exitStatus(P)) < 0 && *timeout > 0 && ! (Run.flags & Run_Stopped));
-                        if (*timeout <= 0)
+                                *usec_timeout -= RETRY_INTERVAL;
+                        } while ((status = Process_exitStatus(P)) < 0 && *usec_timeout > 0 && ! (Run.flags & Run_Stopped));
+                        if (*usec_timeout <= 0)
                                 snprintf(msg, msglen, "Program '%s' timed out after %s", Util_commandDescription(c, (char[STRLEN]){}), Fmt_time2str(_timeoutMilli, (char[11]){}));
                         int n, total = 0;
                         char buf[STRLEN];
                         do {
-                                if ((n = _getOutput(Process_getErrorStream(P), buf, sizeof(buf))) <= 0)
-                                        n = _getOutput(Process_getInputStream(P), buf, sizeof(buf));
+                                if ((n = _getOutput(Process_errorStream(P), buf, sizeof(buf))) <= 0)
+                                        n = _getOutput(Process_inputStream(P), buf, sizeof(buf));
                                 if (n > 0) {
                                         buf[n] = 0;
                                         DEBUG("%s", buf);
                                         // Report the first message (override existing plain timeout message if some program output is available)
                                         if (! total)
-                                                snprintf(msg, msglen, "'%s': %s%s", Util_commandDescription(c, (char[STRLEN]){}), *timeout <= 0 ? "Program timed out -- " : "", buf);
+                                                snprintf(msg, msglen, "'%s': %s%s", Util_commandDescription(c, (char[STRLEN]){}), *usec_timeout <= 0 ? "Program timed out -- " : "", buf);
                                         total += n;
                                 }
                         } while (n > 0 && Run.debug && total < 2048); // Limit the debug output (if the program will have endless output, such as 'yes' utility, we have to stop at some point to not spin here forever)
-                        Process_free(&P); // Will kill the program if still running
+                        Process_detach(P);
+                        Process_free(&P);
                 } else {
                         snprintf(msg, msglen, "Program %s failed: %s", c->arg[0], System_lastError());
                 }
@@ -166,30 +167,30 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, long
 }
 
 
-static Process_Status _waitProcessStart(Service_T s, long long *timeout) {
-        long wait = RETRY_INTERVAL;
+static Process_Status _waitProcessStart(Service_T s, long long *usec_timeout) {
+        long long usec_wait = RETRY_INTERVAL;
         do {
-                Time_usleep(wait);
+                Time_usleep(usec_wait);
                 pid_t pid = ProcessTree_findProcess(s);
                 if (pid) {
                         ProcessTree_init(ProcessEngine_None);
                         ProcessTree_updateProcess(s, pid);
                         return Process_Started;
                 }
-                *timeout -= wait;
-                wait = wait < 1000000 ? wait * 2 : 1000000; // double the wait during each cycle until 1s is reached (ProcessTree_findProcess can be heavy and we don't want to drain power every 100ms on mobile devices)
-        } while (*timeout > 0 && ! (Run.flags & Run_Stopped));
+                *usec_timeout -= usec_wait;
+                usec_wait = usec_wait < 1000000 ? usec_wait * 2 : 1000000; // double the wait during each cycle until 1s is reached (ProcessTree_findProcess can be heavy and we don't want to drain power every 100ms on mobile devices)
+        } while (*usec_timeout > 0 && ! (Run.flags & Run_Stopped));
         return Process_Stopped;
 }
 
 
-static Process_Status _waitProcessStop(int pid, long long *timeout) {
+static Process_Status _waitProcessStop(int pid, long long *usec_timeout) {
         do {
                 Time_usleep(RETRY_INTERVAL);
                 if (! pid || (getpgid(pid) == -1 && errno != EPERM))
                         return Process_Stopped;
-                *timeout -= RETRY_INTERVAL;
-        } while (*timeout > 0 && ! (Run.flags & Run_Stopped));
+                *usec_timeout -= RETRY_INTERVAL;
+        } while (*usec_timeout > 0 && ! (Run.flags & Run_Stopped));
         return Process_Started;
 }
 
@@ -203,11 +204,11 @@ static State_Type _check(Service_T s) {
         rv = s->check(s);
         if (s->type == Service_Program && s->program->P) {
                 // check program executes the program and needs to be called again to collect the exit value and evaluate the status
-                long long timeout = s->program->timeout * USEC_PER_MSEC;
+                long long usec_timeout = s->program->timeout * USEC_PER_MSEC;
                 do {
                         Time_usleep(RETRY_INTERVAL);
-                        timeout -= RETRY_INTERVAL;
-                } while (Process_exitStatus(s->program->P) < 0 && timeout > 0LL && ! (Run.flags & Run_Stopped));
+                        usec_timeout -= RETRY_INTERVAL;
+                } while (Process_exitStatus(s->program->P) < 0 && usec_timeout > 0LL && ! (Run.flags & Run_Stopped));
                 rv = s->check(s);
         }
         s->mode = original;
@@ -243,9 +244,9 @@ static bool _doStart(Service_T s) {
                         if (s->type != Service_Process || ! ProcessTree_findProcess(s)) {
                                 Log_info("'%s' start: '%s'\n", s->name, Util_commandDescription(s->start, (char[STRLEN]){}));
                                 char msg[1024];
-                                long long timeout = s->start->timeout * USEC_PER_MSEC;
-                                int status = _commandExecute(s, s->start, msg, sizeof(msg), &timeout);
-                                if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &timeout) != Process_Started)) {
+                                long long usec_timeout = s->start->timeout * USEC_PER_MSEC;
+                                int status = _commandExecute(s, s->start, msg, sizeof(msg), &usec_timeout);
+                                if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &usec_timeout) != Process_Started)) {
                                         Event_post(s, Event_Exec, State_Failed, s->action_EXEC, "failed to start (exit status %d) -- %s", status, *msg ? msg : "no output");
                                         rv = false;
                                 } else {
@@ -266,9 +267,9 @@ static bool _doStart(Service_T s) {
 }
 
 
-static int _executeStop(Service_T s, char *msg, int msglen, long long *timeout) {
+static int _executeStop(Service_T s, char *msg, int msglen, long long *usec_timeout) {
         Log_info("'%s' stop: '%s'\n", s->name, Util_commandDescription(s->stop, (char[STRLEN]){}));
-        return _commandExecute(s, s->stop, msg, msglen, timeout);
+        return _commandExecute(s, s->stop, msg, msglen, usec_timeout);
 }
 
 
@@ -293,16 +294,16 @@ static bool _doStop(Service_T s, bool unmonitor) {
                 if (s->monitor != Monitor_Not) {
                         int exitStatus;
                         char msg[1024];
-                        long long timeout = s->stop->timeout * USEC_PER_MSEC;
+                        long long usec_timeout = s->stop->timeout * USEC_PER_MSEC;
                         if (s->type == Service_Process) {
                                 int pid = ProcessTree_findProcess(s);
                                 if (pid) {
-                                        exitStatus = _executeStop(s, msg, sizeof(msg), &timeout);
-                                        rv = _waitProcessStop(pid, &timeout) == Process_Stopped ? true : false;
+                                        exitStatus = _executeStop(s, msg, sizeof(msg), &usec_timeout);
+                                        rv = _waitProcessStop(pid, &usec_timeout) == Process_Stopped ? true : false;
                                         _evaluateStop(s, rv, exitStatus, msg);
                                 }
                         } else {
-                                exitStatus = _executeStop(s, msg, sizeof(msg), &timeout);
+                                exitStatus = _executeStop(s, msg, sizeof(msg), &usec_timeout);
                                 rv = exitStatus >= 0 ? true : false;
                                 _evaluateStop(s, rv, exitStatus, msg);
                         }
@@ -331,9 +332,9 @@ static bool _doRestart(Service_T s) {
                 Log_info("'%s' restart: '%s'\n", s->name, Util_commandDescription(s->restart, (char[STRLEN]){}));
                 Util_resetInfo(s);
                 char msg[1024];
-                long long timeout = s->restart->timeout * USEC_PER_MSEC;
-                int status = _commandExecute(s, s->restart, msg, sizeof(msg), &timeout);
-                if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &timeout) != Process_Started)) {
+                long long usec_timeout = s->restart->timeout * USEC_PER_MSEC;
+                int status = _commandExecute(s, s->restart, msg, sizeof(msg), &usec_timeout);
+                if (status < 0 || (s->type == Service_Process && _waitProcessStart(s, &usec_timeout) != Process_Started)) {
                         rv = false;
                         Event_post(s, Event_Exec, State_Failed, s->action_EXEC, "failed to restart (exit status %d) -- %s", status, msg);
                 } else {
