@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -448,7 +448,7 @@ static void _filesystemFlagsToString(Info_T inf, unsigned long long flags) {
 
 static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char *path, struct statfs *mnt)) {
         int countfs = getfsstat(NULL, 0, MNT_NOWAIT);
-        if (countfs != -1) {
+        if (countfs > 0) {
                 struct statfs *mnt = CALLOC(countfs, sizeof(struct statfs));
                 if ((countfs = getfsstat(mnt, countfs * sizeof(struct statfs), MNT_NOWAIT)) != -1) {
                         for (int i = 0; i < countfs; i++) {
