@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -62,6 +62,7 @@
 #include "event.h"
 #include "state.h"
 #include "MMonit.h"
+#include "spawn.h"
 
 // libmonit
 #include "io/File.h"
@@ -315,7 +316,16 @@ static void _handleAction(Event_T E, Action_T A) {
                 } else if (A->id == Action_Exec) {
                         if (E->state_changed || (E->state && A->repeat && E->count % A->repeat == 0)) {
                                 Log_info("'%s' exec: '%s'\n", E->source->name, Util_commandDescription(A->exec, (char[STRLEN]){}));
-                                spawn(E->source, A->exec, E);
+                                char spawn_error[STRLEN] = {"?"};
+                                if (spawn(&(struct spawn_args_t){
+                                        .S = E->source,
+                                        .cmd = A->exec,
+                                        .E = E,
+                                        .err = spawn_error,
+                                        .errlen = STRLEN
+                                }) < 0) {
+                                        Log_error("'%s' exec failed -- '%s'\n", E->source->name, spawn_error);
+                                }
                                 return;
                         }
                 } else {
@@ -325,6 +335,7 @@ static void _handleAction(Event_T E, Action_T A) {
                         }
                         if (E->source->mode == Monitor_Passive && (A->id == Action_Start || A->id == Action_Stop  || A->id == Action_Restart))
                                 return;
+                        // Warning: the control_service() on stop/unmonitor may free the list of events linked to this service, including this event => do not use event after this call:
                         control_service(E->source->name, A->id);
                 }
         }
