@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -137,7 +137,7 @@ void monit_http(Httpd_Action action) {
 
 
 static void *thread_wrapper(__attribute__ ((unused)) void *arg) {
-        set_signal_block();
+        set_signal_block(false);
         Engine_start();
 #ifdef HAVE_OPENSSL
         Ssl_threadCleanup();
