@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -602,7 +602,7 @@ static HttpResponse create_HttpResponse(Socket_T S) {
  * Create HTTP headers for the given request
  */
 static bool create_headers(HttpRequest req) {
-        unsigned contentLength = 0;
+        int contentLength = 0;
         char line[REQ_STRLEN] = {};
         while (Socket_readLine(req->S, line, sizeof(line)) && ! (Str_isEqual(line, "\r\n") || Str_isEqual(line, "\n"))) {
                 contentLength += strlen(line);
@@ -830,7 +830,7 @@ static bool basic_authenticate(HttpRequest req) {
                 Log_debug("HttpRequest: access denied -- client [%s]: invalid Authorization header\n", NVLSTR(Socket_getRemoteHost(req->S)));
                 return false;
         }
-        if (STR_UNDEF(uname)) {
+        if (! *uname) {
                 Log_debug("HttpRequest: access denied -- client [%s]: empty username\n", NVLSTR(Socket_getRemoteHost(req->S)));
                 return false;
         }
