@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -169,7 +169,7 @@ static void _log(int priority, const char *s, va_list ap) {
                                 vsyslog(priority, s, ap_copy);
                                 va_end(ap_copy);
                         } else if (_LOG) {
-                                fprintf(_LOG, "[%s] %-8s : ", Time_fmt((char[STRLEN]){}, STRLEN, TIMEFORMAT, Time_now()), _priorityDescription(priority));
+                                fprintf(_LOG, "[%s] %-8s : ", Time_localFmt((char[STRLEN]){}, STRLEN, TIMEFORMAT, Time_now()), _priorityDescription(priority));
                                 va_copy(ap_copy, ap);
                                 vfprintf(_LOG, s, ap_copy);
                                 va_end(ap_copy);
@@ -180,13 +180,13 @@ static void _log(int priority, const char *s, va_list ap) {
 }
 
 
-static void _backtrace(void) {
+static void _backtrace(bool force) {
 #ifdef HAVE_BACKTRACE
         int i, frames;
         void *callstack[128];
         char **strs;
 
-        if (Run.debug >= 2) {
+        if (force || Run.debug >= 2) {
                 frames = backtrace(callstack, 128);
                 strs = backtrace_symbols(callstack, frames);
                 Log_debug("-------------------------------------------------------------------------------\n");
@@ -241,7 +241,7 @@ void Log_emergency(const char *s, ...) {
         va_start(ap, s);
         _log(LOG_EMERG, s, ap);
         va_end(ap);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -256,7 +256,7 @@ void Log_vemergency(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         _log(LOG_EMERG, s, ap);
         va_end(ap_copy);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -270,7 +270,7 @@ void Log_alert(const char *s, ...) {
         va_start(ap, s);
         _log(LOG_ALERT, s, ap);
         va_end(ap);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -285,7 +285,7 @@ void Log_valert(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         _log(LOG_ALERT, s, ap);
         va_end(ap_copy);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -299,7 +299,7 @@ void Log_critical(const char *s, ...) {
         va_start(ap, s);
         _log(LOG_CRIT, s, ap);
         va_end(ap);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -314,7 +314,7 @@ void Log_vcritical(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         _log(LOG_CRIT, s, ap);
         va_end(ap_copy);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -328,8 +328,10 @@ void Log_abort_handler(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         _log(LOG_CRIT, s, ap);
         va_end(ap_copy);
-        if (Run.debug)
+        _backtrace(true); // Always log backtrace on abort (asserts, etc.)
+        if (Run.debug) {
                 abort();
+        }
         exit(1);
 }
 
@@ -344,7 +346,7 @@ void Log_error(const char *s, ...) {
         va_start(ap, s);
         _log(LOG_ERR, s, ap);
         va_end(ap);
-        _backtrace();
+        _backtrace(false);
 }
 
 
@@ -359,7 +361,7 @@ void Log_verror(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         _log(LOG_ERR, s, ap);
         va_end(ap_copy);
-        _backtrace();
+        _backtrace(false);
 }
 
 
