@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -118,9 +118,9 @@
 #define STRERROR            strerror(errno)
 #define STRLEN             256
 #ifndef USEC_PER_SEC
-#define USEC_PER_SEC       1000000L
+#define USEC_PER_SEC       1000000LL
 #endif
-#define USEC_PER_MSEC      1000L
+#define USEC_PER_MSEC      1000LL
 
 #define ARGMAX             64
 #define MYPIDDIR           PIDDIR
@@ -156,19 +156,19 @@ typedef enum {
         Run_DoReload             = 0x800,                        /**< Reload Monit */
         Run_DoWakeup             = 0x1000,                       /**< Wakeup Monit */
         Run_Batch                = 0x2000                      /**< CLI batch mode */
-} __attribute__((__packed__)) Run_Flags;
+} Run_Flags;
 
 
 typedef enum {
         ProcessEngine_None               = 0x0,
         ProcessEngine_CollectCommandLine = 0x1
-} __attribute__((__packed__)) ProcessEngine_Flags;
+} ProcessEngine_Flags;
 
 
 typedef enum {
         Httpd_Start = 1,
         Httpd_Stop
-} __attribute__((__packed__)) Httpd_Action;
+} Httpd_Action;
 
 
 typedef enum {
@@ -177,7 +177,7 @@ typedef enum {
         Every_SkipCycles,
         Every_Cron,
         Every_NotInCron
-} __attribute__((__packed__)) Every_Type;
+} Every_Type;
 
 
 typedef enum {
@@ -187,7 +187,7 @@ typedef enum {
         State_ChangedNot = 0x4,
         State_Init       = 0x8,
         State_None       = State_Init // Alias
-} __attribute__((__packed__)) State_Type;
+} State_Type;
 
 
 typedef enum {
@@ -198,7 +198,7 @@ typedef enum {
         Operator_Equal,
         Operator_NotEqual,
         Operator_Changed
-} __attribute__((__packed__)) Operator_Type;
+} Operator_Type;
 
 
 typedef enum {
@@ -206,7 +206,7 @@ typedef enum {
         Timestamp_Access,
         Timestamp_Change,
         Timestamp_Modification
-} __attribute__((__packed__)) Timestamp_Type;
+} Timestamp_Type;
 
 
 typedef enum {
@@ -217,13 +217,13 @@ typedef enum {
         Httpd_UnixGid                     = 0x8,  // Unix socket: override GID
         Httpd_UnixPermission              = 0x10, // Unix socket: override permissions
         Httpd_Signature                   = 0x20  // Server Signature enabled
-} __attribute__((__packed__)) Httpd_Flags;
+} Httpd_Flags;
 
 
 typedef enum {
         Http_Head = 1,
         Http_Get
-} __attribute__((__packed__)) Http_Method;
+} Http_Method;
 
 
 typedef enum {
@@ -232,7 +232,7 @@ typedef enum {
         Time_Hour   = 3600,
         Time_Day    = 86400,
         Time_Month  = 2678400
-} __attribute__((__packed__)) Time_Type;
+} Time_Type;
 
 
 typedef enum {
@@ -244,20 +244,20 @@ typedef enum {
         Action_Unmonitor,
         Action_Start,
         Action_Monitor
-} __attribute__((__packed__)) Action_Type;
+} Action_Type;
 
 
 typedef enum {
         Monitor_Active = 0,
         Monitor_Passive
-} __attribute__((__packed__)) Monitor_Mode;
+} Monitor_Mode;
 
 
 typedef enum {
         Onreboot_Start = 0,
         Onreboot_Nostart,
         Onreboot_Laststate
-} __attribute__((__packed__)) Onreboot_Type;
+} Onreboot_Type;
 
 
 typedef enum {
@@ -265,14 +265,14 @@ typedef enum {
         Monitor_Yes     = 0x1,
         Monitor_Init    = 0x2,
         Monitor_Waiting = 0x4
-} __attribute__((__packed__)) Monitor_State;
+} Monitor_State;
 
 
 typedef enum {
         Connection_Failed = 0,
         Connection_Ok,
         Connection_Init
-} __attribute__((__packed__)) Connection_State;
+} Connection_State;
 
 
 typedef enum {
@@ -286,7 +286,7 @@ typedef enum {
         Service_Program,
         Service_Net,
         Service_Last = Service_Net
-} __attribute__((__packed__)) Service_Type;
+} Service_Type;
 
 
 typedef enum {
@@ -327,7 +327,7 @@ typedef enum {
         Resource_LoadAveragePerCore5m,
         Resource_LoadAveragePerCore15m,
         Resource_HardLink                   // Used by check file, fifo and directory
-} __attribute__((__packed__)) Resource_Type;
+} Resource_Type;
 
 
 
@@ -336,7 +336,7 @@ typedef enum {
         Digest_Crypt,
         Digest_Md5,
         Digest_Pam
-} __attribute__((__packed__)) Digest_Type;
+} Digest_Type;
 
 
 typedef enum {
@@ -344,7 +344,7 @@ typedef enum {
         Unit_Kilobyte = 1024,
         Unit_Megabyte = 1048576,
         Unit_Gigabyte = 1073741824
-} __attribute__((__packed__)) Unit_Type;
+} Unit_Type;
 
 
 typedef enum {
@@ -352,7 +352,7 @@ typedef enum {
         Hash_Md5,
         Hash_Sha1,
         Hash_Default = Hash_Md5
-} __attribute__((__packed__)) Hash_Type;
+} Hash_Type;
 
 
 typedef enum {
@@ -360,14 +360,14 @@ typedef enum {
         Handler_Alert     = 0x1,
         Handler_Mmonit    = 0x2,
         Handler_Max       = Handler_Mmonit
-} __attribute__((__packed__)) Handler_Type;
+} Handler_Type;
 
 
 typedef enum {
         MmonitCompress_Init = 0,
         MmonitCompress_No,
         MmonitCompress_Yes
-} __attribute__((__packed__)) MmonitCompress_Type;
+} MmonitCompress_Type;
 
 
 typedef enum {
@@ -383,7 +383,7 @@ typedef enum {
         Statistics_FiledescriptorsPerSystem     = 0x200,
         Statistics_FiledescriptorsPerProcess    = 0x400,
         Statistics_FiledescriptorsPerProcessMax = 0x800
-} __attribute__((__packed__)) Statistics_Flags;
+} Statistics_Flags;
 
 
 /* Length of the longest message digest in bytes */
@@ -442,16 +442,16 @@ typedef char MD_T[MD_SIZE];
 
 /** Defines monit limits object */
 typedef struct Limits_T {
-        size_t   fileContentBuffer;  /**< Maximum tested file content length [B] */
-        int64_t programOutput;           /**< Program output truncate limit [B] */
-        int64_t sendExpectBuffer;  /**< Maximum send/expect response length [B] */
-        int64_t httpContentBuffer;  /**< Maximum tested HTTP content length [B] */
-        int64_t networkTimeout;               /**< Default network timeout [ms] */
-        int64_t programTimeout;               /**< Default program timeout [ms] */
-        int64_t stopTimeout;                     /**< Default stop timeout [ms] */
-        int64_t startTimeout;                   /**< Default start timeout [ms] */
-        int64_t restartTimeout;               /**< Default restart timeout [ms] */
-        int64_t execTimeout;         /**< Default test action exec timeout [ms] */
+        size_t fileContentBuffer;    /**< Maximum tested file content length [B] */
+        int programOutput;                /**< Program output truncate limit [B] */
+        int sendExpectBuffer;       /**< Maximum send/expect response length [B] */
+        int httpContentBuffer;       /**< Maximum tested HTTP content length [B] */
+        int networkTimeout;                    /**< Default network timeout [ms] */
+        int programTimeout;                    /**< Default program timeout [ms] */
+        int stopTimeout;                          /**< Default stop timeout [ms] */
+        int startTimeout;                        /**< Default start timeout [ms] */
+        int restartTimeout;                    /**< Default restart timeout [ms] */
+        int execTimeout;              /**< Default test action exec timeout [ms] */
 } Limits_T;
 
 
@@ -1348,7 +1348,7 @@ struct Run_T {
         MD_T id;                                              /**< Unique monit id */
         Limits_T limits;                                       /**< Default limits */
         struct SslOptions_T ssl;                          /**< Default SSL options */
-        int  polltime;        /**< In daemon mode, the sleeptime (sec) between run */
+        int polltime;         /**< In daemon mode, the sleeptime (sec) between run */
         int  startdelay;  /**< the sleeptime [s] on first start after machine boot */
         int  facility;              /** The facility to use when running openlog() */
         int  eventlist_slots;          /**< The event queue size - number of slots */
@@ -1441,7 +1441,6 @@ extern const char *Httpmethod_Names[];
 bool parse(char *);
 bool control_service(const char *, Action_Type);
 bool control_service_string(List_T, const char *);
-void spawn(Service_T, command_t, Event_T);
 bool Log_init(void);
 void Log_emergency(const char *, ...) __attribute__((format (printf, 1, 2)));
 void Log_alert(const char *, ...) __attribute__((format (printf, 1, 2)));
@@ -1473,7 +1472,7 @@ bool sendmail(Mail_T);
 void init_env(void);
 void monit_http(Httpd_Action);
 bool can_http(void);
-void set_signal_block(void);
+void set_signal_block(bool);
 State_Type check_process(Service_T);
 State_Type check_filesystem(Service_T);
 State_Type check_file(Service_T);
