@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -99,7 +99,7 @@
 typedef enum {
         Connection_Client = 0,
         Connection_Server
-} __attribute__((__packed__)) Connection_Type;
+} Connection_Type;
 
 
 // One TCP frame data size
@@ -588,6 +588,8 @@ static void _testIp(Port_T p) {
                                 {
                                         S = _createIpSocket(p->hostname, r->ai_addr, r->ai_addrlen, p->outgoing.addrlen ? (struct sockaddr *)&(p->outgoing.addr) : NULL, p->outgoing.addrlen, r->ai_family, r->ai_socktype, r->ai_protocol, p->timeout);
                                         S->Port = p;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wshadow"
                                         TRY
                                         {
                                                 if (p->target.net.ssl.options.flags == SSL_Enabled) {
@@ -605,6 +607,7 @@ static void _testIp(Port_T p) {
 #endif
                                         }
                                         END_TRY;
+#pragma GCC diagnostic pop
                                         is_available = Connection_Ok;
 
                                 }
