@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -88,7 +88,7 @@ typedef enum {
         MTA_StartTLS  = 0x1,
         MTA_AuthPlain = 0x2,
         MTA_AuthLogin = 0x4
-} __attribute__((__packed__)) MTA_Flags;
+} MTA_Flags;
 
 
 typedef enum {
@@ -102,7 +102,7 @@ typedef enum {
         SMTP_DataBegin,
         SMTP_DataCommit,
         SMTP_Quit
-} __attribute__((__packed__)) SMTP_State;
+} SMTP_State;
 
 
 #define T SMTP_T
