@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -348,17 +348,37 @@ time_t ProcessTree_getProcessUptime(pid_t pid) {
 }
 
 
+static pid_t _isProcessRunning(Service_T s, pid_t pid) {
+        pid_t groupLeaderPid = getpgid(pid);
+        if (groupLeaderPid > -1) {
+                // The PID may belong to LWP task on some platforms (e.g. Linux). We need to check that the PID belongs to the main thread to make sure it is the real process PID
+                pid_t mainPid = Sysdep_getMainThread(pid);
+                if (mainPid == pid)
+                        return pid;
+                else
+                        DEBUG("'%s' The PID %d was found, but it's not main process thread. The PID of the original process was likely reused for the LWP belonging to another process with PID %d\n", s->name, pid, mainPid);
+        } else if (errno == EPERM) {
+                // The process is running, but we don't have permissions (at this point we're not able to differentiate LWP from normal process though)
+                return pid;
+        } else {
+                DEBUG("'%s' The PID %d is not running -- %s\n", s->name, pid, STRERROR);
+        }
+        return 0;
+}
+
+
 pid_t ProcessTree_findProcess(Service_T s) {
         assert(s);
-        // Test the cached PID first
-        if (s->inf.process->pid > 0) {
-                errno = 0;
-                if (getpgid(s->inf.process->pid) > -1 || errno == EPERM)
-                        return s->inf.process->pid;
-        }
-        // If the cached PID is not running, scan for the process again
         if (s->matchlist) {
-                // Update the process tree including command line
+                // PROCMATCH check
+
+                // Test the cached PID first
+                if (s->inf.process->pid > 0) {
+                        pid_t pid = _isProcessRunning(s, s->inf.process->pid);
+                        if (pid)
+                                return pid;
+                }
+                // If the cached PID is not running, scan for the process again. Update the process tree including command line.
                 ProcessTree_init(ProcessEngine_CollectCommandLine);
                 if (Run.flags & Run_ProcessEngineEnabled) {
                         int pid = _match(s->matchlist->regex_comp);
@@ -370,12 +390,15 @@ pid_t ProcessTree_findProcess(Service_T s) {
                         return ! (s->error & Event_NonExist);
                 }
         } else {
+                // PIDFILE check
+
+                // Re-read PID from the file
                 pid_t pid = Util_getPid(s->path);
+
                 if (pid > 0) {
-                        errno = 0;
-                        if (getpgid(pid) > -1 || errno == EPERM)
-                                return pid;
-                        DEBUG("'%s' process test failed [pid=%d] -- %s\n", s->name, pid, STRERROR);
+                        pid_t foundPid = _isProcessRunning(s, pid);
+                        if (foundPid)
+                                return foundPid;
                 }
         }
         Util_resetInfo(s);
@@ -443,3 +466,11 @@ void ProcessTree_testMatch(char *pattern) {
         regfree(regex_comp);
         FREE(regex_comp);
 }
+
+
+void ProcessTree_visit(void visitor(ProcessTree_T *p, void *ap), void *ap) {
+        ProcessTree_init(ProcessEngine_None);
+        for (int i = 0; i < ptreesize; i++) {
+                visitor(&ptree[i], ap);
+        }
+}
