@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -335,3 +335,8 @@ bool available_statistics(SystemInfo_T *si) {
         return true;
 }
 
+
+pid_t Sysdep_getMainThread(pid_t pid) {
+        return pid;
+}
+
