@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,7 +38,7 @@
 /**
  *  A WebSocket test.
  *
- *  http://tools.ietf.org/html/rfc6455
+ *  https://datatracker.ietf.org/doc/html/rfc6455
  *
  *  Establish websocket connection, send ping and close.
  *
@@ -106,7 +106,7 @@ void check_websocket(Socket_T socket) {
                          P->parameters.websocket.request ? P->parameters.websocket.request : "/",
                          P->parameters.websocket.host ? P->parameters.websocket.host : Util_getHTTPHostHeader(socket, buf, sizeof(buf)),
                          P->parameters.websocket.version,
-                         P->parameters.websocket.origin ? P->parameters.websocket.origin : "http://www.mmonit.com") < 0)
+                         P->parameters.websocket.origin ? P->parameters.websocket.origin : "https://mmonit.com") < 0)
         {
                 THROW(IOException, "WEBSOCKET: error sending data -- %s", STRERROR);
         }
