@@ -10,7 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -114,7 +114,7 @@ typedef enum {
 /* Extended format version 4 */
 typedef struct mystate4 {
         char               name[STRLEN];
-        int32_t            type;
+        uint32_t           type;
         int32_t            monitor;
         int32_t            nstart;
         int32_t            ncycle;
@@ -160,7 +160,7 @@ typedef struct mystate4 {
 /* Extended format version 3 */
 typedef struct mystate3 {
         char               name[STRLEN];
-        int32_t            type;
+        uint32_t           type;
         int32_t            monitor;
         int32_t            nstart;
         int32_t            ncycle;
@@ -204,7 +204,7 @@ typedef struct mystate3 State2_T;
 /* Extended format version 1 */
 typedef struct mystate1 {
         char               name[STRLEN];
-        int32_t            type;
+        uint32_t           type;
         int32_t            monitor;
         int32_t            nstart;
         int32_t            ncycle;
